@@ -33,9 +33,6 @@ MainWindow::MainWindow(QWidget *parent) :
     progress3.setValue(50);
     QRegExp regexer_snap("^[0-9]{1,2}$");
     progress3.setValue(60);
-  //  QValidator* actualvalidator;
-    // actualvalidator = new QRegExpValidator(regexer, this);
-    //QRegExpValidator validator();
     ui->font1->setValidator(new QRegExpValidator(regexer, ui->font1));
     ui->font2->setValidator(new QRegExpValidator(regexer, ui->font2));
     ui->font3->setValidator(new QRegExpValidator(regexer, ui->font3));
@@ -164,19 +161,12 @@ void MainWindow::readgtkrc()
     icontheme.remove(QChar(' '));
     icontheme.simplified();
     int indeksi = ui->Iconset->findText(icontheme);
- //   if (indeksi) {
-        ui->Iconset->removeItem(indeksi);
-  //  }
-  //  ui->Iconset->setDuplicatesEnabled();
-  //  ui->Iconset->insertPolicy(1);
-    ui->Iconset->insertItem(0, icontheme);
-    ui->Iconset->setCurrentIndex(0);
+    ui->Iconset->setCurrentIndex(indeksi);
 }
 
 void MainWindow::writeSettings()
 {
     QSettings sett("ThemeCustomizer", "Boxes");
-//    sett.setValue("icons", ui->Icons->currentIndex());
     sett.setValue("snap", ui->Snap->text());
     sett.setValue("fontsize", ui->FontSize->currentIndex());
     sett.setValue("iconset", ui->Iconset->currentIndex());
@@ -291,9 +281,6 @@ void MainWindow::processFinished(int)
 
         sleep(10);
 
-   //     QProcess *process8 = new QProcess(this);
-   //     process8->start("/usr/bin/run-standalone.sh dbus-send --print-reply --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:\"All done! Restarting device is recommended to reload all new values.\" uint32:0 string:'NAO OK!'");
-
         sleep(5);
 
         QProcess *process7 = new QProcess(this);
@@ -302,7 +289,7 @@ void MainWindow::processFinished(int)
 
     progress.cancel();
     oldfonts();
-//        writeSettings();
+
 }
 
 void MainWindow::on_horizontalSlider_valueChanged(int value)
